==> james-project-3.5.0-source-release.zip: james-project-3.5.0/server/mailet/mock-smtp-server/src/main/java/org/apache/james/mock/smtp/server/MockSMTPServerMain.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mock.smtp.server;

import org.apache.james.util.Port;

public class MockSMTPServerMain {
    private static final Port HTTP_PORT = new Port(8000);
    private static final Port SMTP_PORT = new Port(25);

    public static void main(String[] args) throws Exception {
        SMTPBehaviorRepository behaviorRepository = new SMTPBehaviorRepository();
        ReceivedMailRepository receivedMailRepository = new ReceivedMailRepository();

        HTTPConfigurationServer httpConfigurationServer = HTTPConfigurationServer.onPort(behaviorRepository, receivedMailRepository, HTTP_PORT);
        MockSMTPServer mockSMTPServer = MockSMTPServer.onPort(behaviorRepository, receivedMailRepository, SMTP_PORT);
        httpConfigurationServer.start();
        mockSMTPServer.start();
    }
}

==> james-project-3.8.2-source-release.zip: james-project-3.8.2/server/mailet/mock-smtp-server/src/main/java/org/apache/james/mock/smtp/server/MockSMTPServerMain.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mock.smtp.server;

import org.apache.james.util.Port;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class MockSMTPServerMain {
    private static final Logger LOGGER = LoggerFactory.getLogger(MockSMTPServerMain.class);
    private static final Port HTTP_PORT = new Port(8000);
    private static final Port SMTP_PORT = new Port(25);

    public static void main(String[] args) {
        SMTPBehaviorRepository behaviorRepository = new SMTPBehaviorRepository();
        ReceivedMailRepository receivedMailRepository = new ReceivedMailRepository();

        HTTPConfigurationServer httpConfigurationServer = HTTPConfigurationServer.onPort(behaviorRepository, receivedMailRepository, HTTP_PORT);
        MockSMTPServer mockSMTPServer = MockSMTPServer.onPort(behaviorRepository, receivedMailRepository, SMTP_PORT);
        httpConfigurationServer.start();
        mockSMTPServer.start();
        LOGGER.info("Mock SMTP server started");
    }
}
